<!-- AreaManage 行政区域管理 -->
<template>
    <div class="full-page bg">
        <el-row class="table-container">
            <el-col :span="10">
                <div class="search-wrapper">
                    <el-input
                        style="width: 100%"
                        clearable
                        v-model="filterText"
                        @change="handleSearch"
                        placeholder="请输入行政区域名"
                    ></el-input>
                </div>
                <div class="tree-wrapper">
                    <el-tree
                        ref="tree"
                        :data="data"
                        node-key="id"
                        default-expand-all
                        :expand-on-click-node="false"
                        :filter-node-method="filterNode"
                    >
                        <span
                            class="custom-tree-node"
                            slot-scope="{node, data}"
                        >
                            <span>{{ node.label }}</span>
                            <el-dropdown @command="handleCommand">
                                <span class="el-dropdown-link">
                                    <i class="el-icon-more el-icon--right"></i>
                                </span>
                                <el-dropdown-menu slot="dropdown">
                                    <el-dropdown-item command="append"
                                        >新增</el-dropdown-item
                                    >
                                    <el-dropdown-item command="edit"
                                        >编辑</el-dropdown-item
                                    >
                                    <el-dropdown-item command="remove"
                                        >删除</el-dropdown-item
                                    >
                                </el-dropdown-menu>
                            </el-dropdown>
                            <!-- <span>
                                <i
                                    class="el-icon-plus"
                                    size="mini"
                                    @click="() => remove(node, data)"
                                />
                                <i
                                    class="el-icon-edit"
                                    size="mini"
                                    @click="() => remove(node, data)"
                                />
                                <i
                                    class="el-icon-delete"
                                    size="mini"
                                    @click="() => remove(node, data)"
                                />
                            </span> -->
                        </span>
                    </el-tree>
                </div>
            </el-col>
            <el-col :span="14">
                <el-form
                    ref="form"
                    :rules="rules"
                    :model="formData"
                    label-width="auto"
                    class="form-wrapper"
                >
                    <el-form-item label="父级行政区域名" prop="name">
                        <el-input
                            style="width: 100%"
                            clearable
                            v-model="formData.name"
                            placeholder="请输入父级行政区域名"
                        ></el-input>
                    </el-form-item>
                    <el-form-item label="行政区域名" prop="name">
                        <el-input
                            style="width: 100%"
                            clearable
                            v-model="formData.name"
                            placeholder="请输入行政区域名"
                        ></el-input>
                    </el-form-item>
                    <el-form-item label="邮政编码" prop="name">
                        <el-input
                            style="width: 100%"
                            clearable
                            v-model="formData.name"
                            placeholder="请输入邮政编码"
                        ></el-input>
                    </el-form-item>
                </el-form>
                <div v-if="isShowButton" class="btn-wrapper">
                    <el-button @click="handleCancel">取消</el-button>
                    <el-button type="primary" @click="handleSubmit"
                        >确定</el-button
                    >
                </div>
            </el-col>
        </el-row>
    </div>
</template>
<script>
// import pilotprojects from '@/api/pilotprojects'
import utils from '@/utils.js'
export default {
    name: 'AreaManage',
    components: {},
    data() {
        return {
            rules: {
                name: [
                    {
                        required: true,
                        message: '请输入父级行政区域名',
                        trigger: 'blur',
                    },
                ],
                xb: [
                    {
                        required: true,
                        message: '请输入行政区域名',
                        trigger: 'blur',
                    },
                ],
                tel: [
                    {
                        required: true,
                        message: '请输入邮政编码',
                        trigger: 'blur',
                    },
                ],
            },
            formData: {},
            isShowButton: true,
            filterText: '',
            data: [
                {
                    id: 1,
                    label: '一级 1',
                    children: [
                        {
                            id: 4,
                            label: '二级 1-1',
                            children: [
                                {
                                    id: 9,
                                    label: '三级 1-1-1',
                                },
                                {
                                    id: 10,
                                    label: '三级 1-1-2',
                                },
                            ],
                        },
                    ],
                },
                {
                    id: 2,
                    label: '一级 2',
                    children: [
                        {
                            id: 5,
                            label: '二级 2-1',
                        },
                        {
                            id: 6,
                            label: '二级 2-2',
                        },
                    ],
                },
                {
                    id: 3,
                    label: '一级 3',
                    children: [
                        {
                            id: 7,
                            label: '二级 3-1',
                        },
                        {
                            id: 8,
                            label: '二级 3-2',
                        },
                    ],
                },
            ],
        }
    },
    watch: {
        filterText(val) {
            this.$refs.tree.filter(val)
        },
    },
    methods: {
        handleCancel() {
            this.isShowButton = false
        },
        append(data) {
            const newChild = {id: id++, label: 'testtest', children: []}
            if (!data.children) {
                this.$set(data, 'children', [])
            }
            data.children.push(newChild)
        },

        remove(node, data) {
            const parent = node.parent
            const children = parent.data.children || parent.data
            const index = children.findIndex((d) => d.id === data.id)
            children.splice(index, 1)
        },

        filterNode(value, data) {
            if (!value) return true
            return data.label.indexOf(value) !== -1
        },
    },
}
</script>
<style lang="scss" scoped>
.search-wrapper{
    height: 40px;
}
.tree-wrapper{
    height: calc(100% - 62px);
    margin-top: 20px;
    border: 1px solid #ddd;
    box-sizing: border-box;
    overflow: auto;
    /deep/ .el-tree{
       border:none; 
    }
}
.form-wrapper{
    margin-top: 40px;
}
/deep/.el-col{
    height: 100%;
    position: relative;
    border: 1px solid #E6E6E6;
    box-sizing: border-box;
    padding: 20px;
}
/deep/.el-col-10{
    width: 41%
    
}
/deep/.el-col-14{
    width: 58%;
    margin-left: 1%;
}
.btn-wrapper{
    width: 100%;
    position: absolute;
    bottom: 20px;
    right: 20px;
    text-align: center;
}

</style>